﻿using System;

using Microsoft.Win32;

namespace RegistryHelper
{
    /*
     * This class is used to perform simple registry lookups.
     */
    public class RegistryQuery
    {
        /*
         * Function GetKeyValue
         * @param startingPoint The base folder in the registry to begin the search
         * @param key The path to the value that we want to find
         * @param name The name of the value that we want to find
         * @return string The value of the key from the registry
         * 
         * Determines the value of a key in the registry on the local machine.
         */
        public static string GetKeyValue(RegistryKey startingPoint, string key, string name)
        {
            try
            {
                RegistryKey regKey = startingPoint.OpenSubKey(key);
                if (regKey == null)
                {
                    return null;
                }
                else
                {
                    object value = regKey.GetValue(name);
                    if (value == null)
                    {
                        return null;
                    }
                    return value.ToString();
                }
            }
            catch (Exception)
            {
                return null;
            }
        }

        /*
         * Function GetKeyValue
         * @param remoteName The name of the remote server
         * @param startingPoint The base folder in the registry to begin the search
         * @param key The path to the value that we want to find
         * @param name The name of the value that we want to find
         * @return string The value of the key from the registry
         * 
         * Determines the value of a key in the registry on a remote server.
         */
        public static string GetRemoteKeyValue(string remoteName, RegistryHive startingPoint, string key, string name)
        {
            RegistryKey environmentKey;
            string retval = string.Empty;
                        
            try
            {
                environmentKey = RegistryKey.OpenRemoteBaseKey(startingPoint, remoteName);
                environmentKey = environmentKey.OpenSubKey(key);
                retval = environmentKey.GetValue(name).ToString();
                environmentKey.Close();
            }
            catch (Exception)
            {
                return null;
            }

            return retval;
        }
    }
}
